function pip;
% pairwise invasibility plots
% user defines the fitness function f(y,x) = Reward to y in pop of x
% where x and y are one dimensional variables describing the strategy
% the script outputs the pairwise invasibility plot

function f=fitness(y,x)
    f=2*(x-0.5).^2+(y-0.5).^2-3*(x-0.5).*(y-0.5); %1-x+y.*(1-2.*x);
end

% plot where the advantage is 0
figure(1)
ezplot(@(x,y)fitness(y,x)-fitness(x,x), [0, 1, 0, 1]);

% in 2012 Matlab version, the following should work to plot inequality
% plot(plot::Inequality(fitness(y,x)>fitness(x,x), x=0..1, y=0..1));
% the code below does not work that fast, but works on older versions
figure(2)
mesh=0.01; % the finer the smoother the curves, but also the longer the 
           % calculation time
x=0:mesh:1;
dx=mesh/2;
y=x;  
dy=dx;

[Y,X]=meshgrid(y,x);
S=fitness(Y,X)-fitness(X,X); % fitness advantage
s=sign(S)+2; %s=1 if S<0, s=2 if S=0 and s=3 if S>0

colour=[.5 .5 .5 ;  0 0 0; 1 1 1];
% defined colour scheme so that s=1 will be grey, s=2 black, and s=3 white
% this way white areas are where y can invade
% grey areas are where y does worse than x and
% black areas are where y does equally well as x
axis([x(1)-dx x(length(x))+dx y(1)-dy y(length(y))+dy]); 
hold on;
for ii= 1:length(x)
    for jj=1:length(y)
        xcoord=[x(ii)-dx x(ii)-dx x(ii)+dx x(ii)+dx];
        ycoord=[y(jj)-dy y(jj)+dy y(jj)+dy y(jj)-dy];
        fill(xcoord,ycoord,colour(s(ii,jj),:), 'EdgeColor','none');
    end;
end;
end





