function MS_Haigh;
% Maynard Smith and Haigh 1974 hitch-hiking game
% the function calculates eventual heterozygosity for the fitness neutral 
% locus due to its linkage to another locus
% User specifies a population size N, fitness advantage s of B versus b
% and range for the linkage strength c (c1)

N=10^6; % population size
s=0.025; % fitness of allele b is 1, of allele B is 1+s
c1=linspace(0,0.008, 101); % range of linkage strength from 0 to 0.008

b0=1/N; % initial frequency of allele B
t1=0:10000; % time from 0 to some large number 
            % should be to infinity in theory but must be finite here

[c,t]=meshgrid(c1,t1); % auxiliary variables to use for the sum
Aux=(1-c).^t./(1-b0+b0*(1+s).^(t+1)); % individual summands

alpha=c1*0.5*(1-b0).*sum(Aux,1); % formula for the limit of frequency of A
h1=4*alpha.*(1-alpha); % heterozygozity of the first locus

figure(1)
plot(c1,h1);

axis([0 0.008 0 1.01])
marks=0:0.002:max(c1);
set(gca,'XTickLabel',marks)
set(gca, 'XTick', marks);
xlabel('\it c');
ylabel('Heterozygozity');
end


