function multiplayer_wa
% simulates the multiplayer war of attrition
% players 'generate' the leaving times 'before' the game and
% cannot change the times as others drop
% user defined inputs of this function are
% - reward V to the winner
% - number of players in a contest m
% - probability density function of leaving times of resident players
% - probability density function of leaving times of mutant player
% the output is the mean reward to a mutant (resident) when a 
% single mutant is in the population of residents

%% User defined inputs
V = 10; % reward to players;  
m = 5;  % m players will be in a contest together

function pdfr = pdf_r(x)
    % probability density function for leaving times of residents
    % does not have to integrate to 1 but should be smaller than 1
    pdfr = exp(-x/V);
end

function pdfm = pdf_m(x)
    % probability density function for leaving times of a mutant
    % this is uniformly random on [0 20]
    if x>20 
        pdfm=0;
    else
        pdfm = 1/20;
    end;
end

%% some tweaking parameters
MaxT = 100;  % maximal leaving time
num_rounds = 100; % number of rounds of WA game

%% auxiliary function for generating random numbers
function r=RandNum(pdf, xlim)
    % generates random number between 0 and xlim given probability
    % density function pdf (does not have to integrate to 1, but 
    %        should be below 1)
    % It uses rejection-sampling method. 
    x=rand(1)*xlim;  % generate two randome numbers u and x
    u=rand;
    while u>pdf(x)  % return x only if u<pdf(x), otherwise do again
        x=rand(1)*xlim;
        u=rand;
    end;
    r=x; %finally satisfied, so return  x
end

%% one round of WA game
function reward=one_round_wa(s1,s)
    %returns reward to player 1 using s1 when everybody else uses s
    time=zeros(1,m); % initiate leaving times
    time(1)= RandNum(s1, MaxT); % generate leaving time of p1
    for p=2:m
        time(p) = RandNum(s, MaxT); %generate times of others
    end;
    [order, IX] =sort(time, 'descend'); % order times
    % p1 ended on IX(1)th place. 
    if IX(1) == 1 % p1 won (ties are ignored here)
        reward= V - order(2); % got the reward V ...
        % but had to wait for ituntil the last resident dropped
    else % p1 did not win
        reward = 0 - time(1); % got 0 and lost time waiting
    end;
end

%% repeat many rounds of WA games to get some statistics out of it
mut_pay=zeros(1,num_rounds); % preallocating mutant's payoff
res_pay=zeros(1,num_rounds); % preallocating resident's payoff
for r = 1:num_rounds %do num_rounds of rounds
    mut_pay(r)=one_round_wa(@pdf_m,@pdf_r); % mutant in residents
    res_pay(r)=one_round_wa(@pdf_r,@pdf_r); % residents
end;

%% outputs average score
disp(['Mutant got ' num2str(mean(mut_pay)) ' on average']);
disp(['Resident got ' num2str(mean(res_pay)) ' on average']);
end
